% Last modified: 06/09/2012 by Pete

% truereac      true reaction equation of tracer in system [1,9]
% Re            Reynolds number [50,100]
% randseed      rng seed for observation noise realization (set to -1 to
%               suppress addition of noise to observations)

function Pete_RunTracer( truereac, Re, randseed )

Pete_RunDet( truereac, Re, randseed )

for i = 1:5
    Pete_RunStoch( truereac, Re, randseed, i )
end

Pete_RunEns( truereac, Re, randseed, 1 )

